dwarfdump(1)

dwarfdump - Dumps DWARF debug information of an ELF object

As shipped in IRIX 6.5.15. Last changed in IRIX 6.5.5.

NAME
     dwarfdump - Dumps DWARF debug information of an ELF object

SYNOPSIS
     dwarfdump [-abcdefilmoprsvy] [-t{afv}] [-uobjectfile] filename

IMPLEMENTATION
     IRIX systems

DESCRIPTION
     The dwarfdump command prints DWARF sections as requested by specific
     options.  If no options are specified, nothing is printed.

     The format is intended to be human-readable.  If a script is to parse
     the output, the -d option is useful.

     The format may change from release to release, so it is unwise to
     depend too heavily on the format.

     The dwarfdump command accepts one or more of the following options:

     -a   Dumps all sections.  Same as -bcfilmoprsy -tfv.

     -b   Dumps the .debug_abbrev section.

     -c   Dumps the .debug_loc section.

     -d   Dense mode.  Each die information of the .debug_info section is
          printed in one-line format.  This option does not imply -i.

     -e   Ellipsis mode.  Short names for DW_TAG_* and DW_ATTR_* are used
          in the output for the .debug_info section.

     -f   Dumps the .debug_frame section.

     -h   Dumps the C++ exception handling section (MIPS_EH_REGION).  If -v
          is specified in addition to -h, the exception handling
          supplemental table (MIPS_EH_REGION_SUPP section) is also printed.

     The fields printed out for the exception table are (in the following
     order): region number; kind which can take one three values 't' for
     try block region, 'c' for cleanup region and 'e' for exception
     specification region; the low offset; the high offset; region number
     of parent.

     The supplemental information printed for try block regions include:
     the handler address; flags; type_info (a structure describing the
     type) address.  The supplement information is repeated for every
     handler assoicated with the try block in a new line.

     The supplemental information printed for exception specification
     supplement include: the type_info address and the flags.

     The supplemental information printed for cleanup supplement include:
     the address of the destructor or delete routine; flags; the address of
     the object and the following fields if present (the presence is
     indicated in the flags field): this parameter offset; number of
     elements of the array object; size of each element; the offset of the
     conditional flag; and the address of the guard variable.

     For more details, see the /usr/include/cmplrs/exception_table.h file.

     -i   Dumps the .debug_info section.

     -l   Dumps the .debug_line information.

     -m   Dumps the .debug_macinfo section.

     -o   Dumps the .reloc_debug_* sections.

     -p   Dumps the .debug_pubnames section.

     -r   Dumps the .debug_aranges section.

     -s   Dumps .debug_string section.

     -ta  Same as -tfv.

     -tf  Dumps the .debug_static_funcs section.

     -tv  Dumps the .debug_static_vars section.

     -uofile
          Restricts the dumping of sections to the named object file only.

     -v   Verbose mode.  Shows more detailed information.  Mor detailed
          information about the .debug_frame section prints if 2 or 3 -v
          options are given.

     -w   Dumps the .debug_weaknames section.

     -y   Dumps the .debug_types section.

FILES
     /usr/bin/dwarfdump

SEE ALSO
     elfdump(1)

     This man page is available only online.